#!/usr/bin/env python

import playerlib
import string
import usermsg
import es

def load():
    """Called when the addon is loaded in EventScripts."""
    # Set public var
    global publicVar
    publicVar = es.ServerVar('coloursay_ver', '0.1beta', 'Current version of coloursay.')
    publicVar.makepublic()
    
    # Register some crap
    es.addons.registerSayFilter(sayFilter)
    es.regsaycmd('!coloursay', 'coloursay\saycmd')
    
def unload():
    """Called on addon unload."""
    es.addons.unregisterSayFilter(sayFilter)
    
def round_start(event_var={}):
    """Called on round start."""
    es.msg('\4ColourSay\1 is running on this server. Say \4!coloursay\1 for help.')
    
def saycmd():
    """Called when a player says !coloursay."""
    userid = es.getcmduserid()
    es.msg(userid, '\4ColourSay\1: Use #green in your say message to make the proceeding text green.')
    es.msg(userid, '\4ColourSay\1: Use #team in your say message to make the proceeding text red or blue depending on your team.')
    es.msg(userid, '\4ColourSay\1: Use #gold in your say message to make the proceeding text the default colour.')

def say(userid, text, teamOnly):
    """Formats a message then es.msg's it."""
    # Format the text
    text = string.strip(text, '"')
    text = string.replace(text, '#team', '\3')
    text = string.replace(text, '#green', '\4')
    text = string.replace(text, '#gold', '\1')
    
    # Is the console?
    if int(userid) == -1:
        # Is the console
        es.dbgmsg(0,'Console :  %s' % text)
        for ply in playerlib.getPlayerList('#all'):
            usermsg.echo(int(ply), 'Console :  %s' % text)
            usermsg.saytext2(int(ply), 0, '\1Console\1 :  %s' % text)
        
        # Return
        return
    
    # Get the player's team
    plyObj = playerlib.getPlayer(userid)
    if plyObj.attributes['teamid'] == 1:
        saySpec(userid, text, teamOnly)

    if plyObj.attributes['teamid'] == 2:
        sayT(userid, text, teamOnly)
    
    if plyObj.attributes['teamid'] == 3:
        sayCT(userid, text, teamOnly)
    
    # Cleanup player object
    del plyObj

def sayFilter(userid, text, teamOnly):
    """Filters the text all players say."""
    if '#' in text:
        # Colour codes in the text, print it.
        say(userid, text, teamOnly)
        return 0, '', teamOnly
    else:
        # Say it D:
        return userid, text, teamOnly

    
def sayT(userid, text, teamOnly):
    """Called when a terrorist player says something that needs colouring."""
    # Get the player object
    plyObj = playerlib.getPlayer(userid)
    plyIsDead = plyObj.attributes['isdead']
    plyName = plyObj.attributes['name']
    index = plyObj.attributes['index']
    
    # Is player dead?
    if teamOnly:
        if plyIsDead:
            es.dbgmsg(0,'*DEAD*(Terrorist) %s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#t,#dead'):
                usermsg.echo(int(ply), '*DEAD*(Terrorist) %s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1*DEAD*(Terrorist) \3%s\1 :  %s' % (plyName, text))
        else:
            es.dbgmsg(0,'(Terrorist) %s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#t'):
                usermsg.echo(int(ply), '(Terrorist) %s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1(Terrorist) \3%s\1 :  %s' % (plyName, text))
    else:
        if plyIsDead:
            es.dbgmsg(0,'*DEAD* %s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#dead'):
                usermsg.echo(int(ply), '*DEAD* %s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1*DEAD* \3%s\1 :  %s' % (plyName, text))
        else:
            es.dbgmsg(0,'%s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#all'):
                usermsg.echo(int(ply), '%s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1\3%s\1 :  %s' % (plyName, text))

def sayCT(userid, text, teamOnly):
    """Called when a CT player says something that needs colouring."""
    # Get the player object
    plyObj = playerlib.getPlayer(userid)
    plyIsDead = plyObj.attributes['isdead']
    plyName = plyObj.attributes['name']
    index = plyObj.attributes['index']
    
    # Is player dead?
    if teamOnly:
        if plyIsDead:
            es.dbgmsg(0,'*DEAD*(Counter-Terrorist) %s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#ct,#dead'):
                usermsg.echo(int(ply), '*DEAD*(Counter-Terrorist) %s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1*DEAD*(Counter-Terrorist) \3%s\1 :  %s' % (plyName, text))
        else:
            es.dbgmsg(0,'(Counter-Terrorist) %s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#ct'):
                usermsg.echo(int(ply), '(Counter-Terrorist) %s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1(Counter-Terrorist) \3%s\1 :  %s' % (plyName, text))
    else:
        if plyIsDead:
            es.dbgmsg(0,'*DEAD* %s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#dead'):
                usermsg.echo(int(ply), '*DEAD* %s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1*DEAD* \3%s\1 :  %s' % (plyName, text))
        else:
            es.dbgmsg(0,'%s :  %s' % (plyName, text))
            for ply in playerlib.getPlayerList('#all'):
                usermsg.echo(int(ply), '%s :  %s' % (plyName, text))
                usermsg.saytext2(int(ply), index, '\1\3%s\1 :  %s' % (plyName, text))

def saySpec(userid, text, teamOnly):
    """Called when a Spectator says something that needs colouring."""
    # Get the player object
    plyObj = playerlib.getPlayer(userid)
    plyIsDead = plyObj.attributes['isdead']
    plyName = plyObj.attributes['name']
    index = plyObj.attributes['index']
    
    # Is player dead?
    if teamOnly:
        es.dbgmsg(0,'(Spectator) %s :  %s' % (plyName, text))
        for ply in playerlib.getPlayerList('#spec,#dead'):
            usermsg.echo(int(ply), '(Spectator) %s :  %s' % (plyName, text))
            usermsg.saytext2(int(ply), index, '\1(Spectator) \3%s\1 :  %s' % (plyName, text))
    else:
        es.dbgmsg(0,'*SPEC* %s :  %s' % (plyName, text))
        for ply in playerlib.getPlayerList('#dead'):
            usermsg.echo(int(ply), '*SPEC* %s :  %s' % (plyName, text))
            usermsg.saytext2(int(ply), index, '\1*SPEC* \3%s\1 :  %s' % (plyName, text))
